import uvicorn
from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from app.api.routes import health, tomato, model
from app.core.config import settings

app = FastAPI(
    title=settings.PROJECT_NAME,
    description="Tomato Severity Segmentation Model API",
    version="0.1.0",
    docs_url="/docs",
    redoc_url="/redoc",
)

# Set up CORS
app.add_middleware(
    CORSMiddleware,
    allow_origins=settings.CORS_ORIGINS,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Include API routes
app.include_router(health.router, tags=["health"])
app.include_router(tomato.router, prefix="/api/tomatoes", tags=["tomatoes"])
app.include_router(model.router, prefix="/api/model", tags=["model"])

if __name__ == "__main__":
    uvicorn.run(
        "main:app",
        host="0.0.0.0",
        port=8000,
        reload=settings.DEBUG,
    )